﻿Imports System.Data
Imports System.Data.SqlClient
Imports System.Web
Imports System.Web.UI

'	Author:			Frank

'	Create date:	8-20-13
'	Edit date:		9-09-13

'	Description:	Class to return a stored procedure result set as a dataset . . .

'	Input:          SPName()        <-- stored procedure name as class property
'                   SPPrms()        <-- stored procedure parameters as list of
'                                       SqlParameters class property; possibly
'                                       empty
'
'   Output:         executeSP()     <-- finished result set as .Net DataTable; exposed
'                                       as an object method call

Public Class parentDBObject

    Private local_conn As SqlConnection = databaseConnection.CreateSqlConnection

    Private _SPName As String = ""
    Private _prmList As New List(Of SqlParameter)

    '   Public get-set exposing the private stored procedure name object field . . .

    Public Property SPName() As String
        Get
            Return _SPName
        End Get

        Set(ByVal value As String)
            _SPName = value
        End Set
    End Property

    '   Public get-set exposing the private parameter list object field . . .

    Public Property SPPrms() As List(Of SqlParameter)
        Get
            Return _prmList
        End Get

        Set(ByVal value As List(Of SqlParameter))
            _prmList = value
        End Set
    End Property

    Public Sub New()
        '   Basic constructor . . .
    End Sub

    Public Overridable Function executeSP() As DataTable

        Dim cmd As New SqlCommand
        Dim dt As New DataTable
        Dim da As New SqlDataAdapter
        Dim localPrm As SqlParameter

        '   Make sure that the object has a stored procedure name . . .

        If (String.IsNullOrEmpty(Me.SPName)) Then
            Return Nothing
        End If

        '   Set up the command object, and tie the called stored
        '   procedure to the SPName object property . . .

        cmd.CommandType = CommandType.StoredProcedure
        cmd.CommandText = Me.SPName

        '   The SPPrms object property has all the stored procedure
        '   parameters in a list object, so extract them and add
        '   them to the command object parameters property . . .

        For Each localPrm In Me.SPPrms
            cmd.Parameters.Add(localPrm)
        Next

        '   Set up the command object connection property . . .

        cmd.Connection = Me.local_conn

        '   Use try-catch to run the command object (AKA the
        '   stored procedure) and fill the data set . . .

        Try
            Me.local_conn.Open()
            dt.Clear()
            da.SelectCommand = cmd

            da.Fill(dt)
        Catch ex As Exception
            Dim localAlert As New Page
            localAlert.ClientScript.RegisterStartupScript(localAlert.GetType(), "ShowMessage", String.Format("<script type='text/javascript'>alert('{0}')</script>", ex.ToString()))
        End Try

        '   Clear out the existing parameter collection - each time
        '   a command object runs, it wants a new parameter
        '   collection. Therefore, throw out the existing
        '   parameters collection after command object
        '   execution . . .

        cmd.Parameters.Clear()

        '   Close the connection object ASAP . . .

        Me.local_conn.Close()

        '   Count the rows in the data table; if it has
        '   at least one row, return that row, otherwise
        '   return Nothing . . .

        If (dt.Rows.Count > 0) Then
            Return dt
        Else
            Return Nothing
        End If

    End Function

End Class